@@ -19,7 +19,14 @@
 #'             Passed to \code{boot.ci}.
 #' @param R The number of replications to use for bootstrap.
 #' @param histogram If \code{TRUE}, produces a histogram of bootstrapped values.
-#' @param digits The number of significant digits in the output.              
+#' @param digits The number of significant digits in the output.
+#' @param reportIncomplete If \code{FALSE} (the default),
+#'                         \code{NA} will be reported in cases where there
+#'                         are instances of the calculation of the statistic
+#'                         failing during the bootstrap procedure.
+#'                         In the case of the goodness-of-fit
+#'                         scenario, setting this to \code{TRUE}
+#'                         will have no effect.          
 #' @param ...    Additional arguments passed to \code{chisq.test}.
 #' 
 #' @details  Cohen's w is used as a measure of association
@@ -33,8 +40,8 @@
 #'           the value will always be zero or positive.
 #'           Because of this, if \code{type="perc"},
 #'           the confidence interval will
-#'           never cross zero. In this case, 
-#'           the confidence interval range should not
+#'           never cross zero.
+#'           The confidence interval range should not
 #'           be used for statistical inference.
 #'           However, if \code{type="norm"}, the confidence interval
 #'           may cross zero.  
@@ -50,6 +57,8 @@
 #' @seealso \code{\link{cramerV}} \code{\link{cramerVFit}}
 #' @concept correlation phi cohen w omega
 #' @return A single statistic, Cohen's w.
+#'         Or a small data frame consisting of Cohen's w,
+#'         and the lower and upper confidence limits.
 #'         
 #' @examples
 #' ### Example with table
@@ -78,7 +87,7 @@
 cohenW = function(x, y=NULL, p=NULL,
                   ci=FALSE, conf=0.95, type="perc",
                   R=1000, histogram=FALSE, 
-                  digits=4, ...) {
+                  digits=4, reportIncomplete=FALSE, ...) {
   CW=NULL
   if(is.factor(x)){x=as.vector(x)}
   if(is.factor(y)){y=as.vector(y)}
@@ -105,6 +114,9 @@ cohenW = function(x, y=NULL, p=NULL,
   CW = signif(as.numeric(CW), digits=digits)
   if(ci==FALSE){names(CW) = "Cohen w"; return(CW)}
   
+  if(is.nan(CW) & ci==TRUE){
+    return(data.frame(Cohen.w=CW, lower.ci=NA, upper.ci=NA))} 
+  
   if(ci==TRUE){
   if(is.matrix(x)){x=as.table(x)}
   if(is.table(x)){
@@ -124,33 +136,59 @@ cohenW = function(x, y=NULL, p=NULL,
               c("Cat")])
       rownames(Long) = seq(1:nrow(Long))
     }
-
-  Function = function(input, index){
-             Input = input[index,]
- if(Type==1){
-  Chi.sq = suppressWarnings(chisq.test(Input[,1], Input[,2], correct=FALSE, 
-           ...))
- }
-  
-   if(Type==2){
-    Chi.sq = suppressWarnings(chisq.test(x=table(Input), p=p, 
-      correct=FALSE, ...))
-   }
-  
-  Sum      = sum(Chi.sq$observed)
-  Expected = Chi.sq$expected/Sum
-  Observed = Chi.sq$observed/Sum
-
-  CW       = sqrt(sum((Expected-Observed)^2/Expected))
-  return(CW)
+    
+  if(Type==1){  
+    L1     = length(unique(droplevels(Long[,1])))
+    L2     = length(unique(droplevels(Long[,2])))
   }
+    
+    if(Type==2){
+    L1     = length(unique(droplevels(Long$Cat)))
+  }  
+    
+  Function = function(input, index){
+    Input = input[index,]
+             
+    NOTEQUAL=0
+    if(Type==1){
+      if(length(unique(droplevels(Input[,1]))) != L1 |
+                length(unique(droplevels(Input[,2]))) != L2){NOTEQUAL=1}}
+    
+    if(Type==2){
+      if(length(unique(droplevels(Input))) != L1){NOTEQUAL=1}}
+             
+    if(NOTEQUAL==1){FLAG=1; return(c(NA,FLAG))}
+             
+    if(NOTEQUAL==0){
+             
+    if(Type==1){
+       Chi.sq = suppressWarnings(chisq.test(Input[,1], Input[,2], 
+         correct=FALSE, ...))
+       }
+  
+    if(Type==2){
+       Chi.sq = suppressWarnings(chisq.test(x=table(Input), p=p, 
+         correct=FALSE, ...))
+       }
+  
+    Sum      = sum(Chi.sq$observed)
+    Expected = Chi.sq$expected/Sum
+    Observed = Chi.sq$observed/Sum
+
+    CW       = sqrt(sum((Expected-Observed)^2/Expected))
+    FLAG     = 0
+    return(c(CW,FLAG))}
+    }
 
   Boot = boot(Long, Function, R=R)
   BCI  = boot.ci(Boot, conf=conf, type=type)
-  if(type=="norm") {CI1=BCI$normal[2];  CI2=BCI$normal[3];}
-  if(type=="basic"){CI1=BCI$basic[4];   CI2=BCI$basic[5];}
-  if(type=="perc") {CI1=BCI$percent[4]; CI2=BCI$percent[5];}
-  if(type=="bca")  {CI1=BCI$bca[4];     CI2=BCI$bca[5];}  
+  if(type=="norm") {CI1=BCI$normal[2];  CI2=BCI$normal[3]}
+  if(type=="basic"){CI1=BCI$basic[4];   CI2=BCI$basic[5]}
+  if(type=="perc") {CI1=BCI$percent[4]; CI2=BCI$percent[5]}
+  if(type=="bca")  {CI1=BCI$bca[4];     CI2=BCI$bca[5]}
+  
+  if(Type==1 & sum(Boot$t[,2])>0 & reportIncomplete==FALSE) {CI1=NA; CI2=NA}
+  if(Type==2 & sum(Boot$t[,2])>0) {CI1=NA; CI2=NA}
   
   CI1=signif(CI1, digits=digits)
   CI2=signif(CI2, digits=digits)
