@@ -17,11 +17,17 @@
 #'             Passed to \code{boot.ci}.
 #' @param R The number of replications to use for bootstrap.
 #' @param histogram If \code{TRUE}, produces a histogram of bootstrapped values.
-#' @param digits The number of significant digits in the output.
 #' @param reportIncomplete If \code{FALSE} (the default),
 #'                         \code{NA} will be reported in cases where there
 #'                         are instances of the calculation of the statistic
 #'                         failing during the bootstrap procedure.
+#' @param brute If \code{FALSE}, the default, the statistic is based on the
+#'              U statistic from the \code{wilcox.test} function.
+#'              If \code{TRUE}, the function will compare values
+#'              in the two samples directly.
+#' @param verbose If \code{TRUE}, reports the proportion of ties and
+#'                the proportions of (Ya > Yb) and (Ya < Yb).
+#' @param digits The number of significant digits in the output.      
 #' @param ... Additional arguments passed to the \code{wilcox.test} function. 
 #'             
 #' @details VDA is an effect size statistic appropriate
@@ -29,31 +35,32 @@
 #'          It ranges from 0 to 1, with 0.5 indicating stochastic equality,
 #'          and 1 indicating that the first group dominates the second.
 #'          
-#'          The function calculates VDA from the "W" U statistic from the
-#'          \code{wilcox.test} function.
+#'          By default, the function calculates VDA from the "W" U statistic
+#'          from the \code{wilcox.test} function.
 #'          Specifically, \code{VDA = U/(n1*n2)}.
 #'            
 #'          The input should include either \code{formula} and \code{data};
 #'          or \code{x}, and \code{y}. If there are more than two groups,
 #'          only the first two groups are used.
 #'          
-#'           Currently, the function makes no provisions for \code{NA}
-#'           values in the data.  It is recommended that \code{NA}s be removed
-#'           beforehand.
+#'          Currently, the function makes no provisions for \code{NA}
+#'          values in the data.  It is recommended that \code{NA}s be removed
+#'          beforehand.
 #'           
-#'           When the data in the first group are greater than
-#'           in the second group, vda is greater than 0.5.
-#'           When the data in the second group are greater than
-#'           in the first group, vda is less than 0.5.
-#'           Be cautious with this interpretation, as R will alphabetize
-#'           groups in the formula interface if the grouping variable
-#'           is not already a factor.
+#'          When the data in the first group are greater than
+#'          in the second group, VDA is greater than 0.5.
+#'          When the data in the second group are greater than
+#'          in the first group, VDA is less than 0.5.
+#'          
+#'          Be cautious with this interpretation, as R will alphabetize
+#'          groups in the formula interface if the grouping variable
+#'          is not already a factor.
 #'
-#'           When VDA is close to 0 or close to 1,
-#'           or with small sample size,
-#'           the confidence intervals 
-#'           determined by this
-#'           method may not be reliable, or the procedure may fail.
+#'          When VDA is close to 0 or close to 1,
+#'          or with small sample size,
+#'          the confidence intervals 
+#'          determined by this
+#'          method may not be reliable, or the procedure may fail.
 #'                      
 #' @author Salvatore Mangiafico, \email{mangiafico@njaes.rutgers.edu}
 #' @references \url{http://rcompanion.org/handbook/F_04.html}
@@ -80,8 +87,8 @@
 
 vda = 
  function(formula=NULL, data=NULL, x=NULL, y=NULL, 
-          ci=FALSE, conf=0.95, type="perc", R=1000, histogram=FALSE, digits=3,
-          reportIncomplete=FALSE,
+          ci=FALSE, conf=0.95, type="perc", R=1000, histogram=FALSE, 
+          reportIncomplete=FALSE, brute=FALSE, verbose=FALSE, digits=3,
           ...){
 
   if(!is.null(formula)){
@@ -97,11 +104,33 @@ vda =
    x = c(A, B)
    g = factor(c(rep("A", length(A)), rep("B", length(B))))
   }
-   
+
+  if(brute==FALSE){
   n1  = as.numeric(length(A))
   n2  = as.numeric(length(B))
   U   = suppressWarnings(wilcox.test(x=A, y=B, ...))$statistic
   VDA = signif(U / (n1 * n2), digits=digits)
+  }
+
+  if(brute==TRUE){
+    Matrix = outer(A,B,FUN="-")
+    Diff   = ifelse(Matrix==0, 0.5, Matrix>0)
+    VDA    = signif(mean(Diff), digits=digits)
+  }
+  
+   if(verbose){
+     Matrix = outer(A,B,FUN="-")
+     Out = data.frame(
+       Statistic = c("Proportion Ya > Yb","Proportion Ya < Yb",
+                     "Proportion ties"),
+       Value     = c(signif(mean(Matrix>0), digits=3),
+                     signif(mean(Matrix<0), digits=3),
+                     signif(mean(Matrix==0), digits=3))
+     )
+     cat("\n")
+     print(Out)
+     cat("\n")
+   } 
   
   if(ci==TRUE){
   Data = data.frame(x,g)
@@ -109,15 +138,28 @@ vda =
                     Input = input[index,]
                     if(length(unique(droplevels(Input$g)))==1){
                        FLAG=1
-                       return(c(NA,FLAG))}  
+                       return(c(NA,FLAG))}
+                    
                     if(length(unique(droplevels(Input$g)))>1){
-                        U = suppressWarnings(wilcox.test(x ~ g, 
+                      
+                      if(brute==FALSE){
+                      U = suppressWarnings(wilcox.test(x ~ g, 
                                          data=Input, ...))$statistic
                       n1  = length(Input$x[Input$g==levels(Input$g)[1]])
                       n2  = length(Input$x[Input$g==levels(Input$g)[2]])
                       p   = U / (n1 * n2)
-                      FLAG=0
+                      FLAG=0}
+                      
+                      if(brute==TRUE){
+                      Matrix = outer(Input$x[Input$g==levels(Input$g)[1]],
+                                     Input$x[Input$g==levels(Input$g)[2]],
+                                     FUN="-")
+                         Diff   = ifelse(Matrix==0, 0.5, Matrix>0)
+                         p      = mean(Diff)
+                         FLAG=0}
+                      
                       return(c(p, FLAG))}}
+  
   Boot = boot(Data, Function, R=R)
   BCI  = boot.ci(Boot, conf=conf, type=type)
   if(type=="norm") {CI1=BCI$normal[2];  CI2=BCI$normal[3];}
